@@ -2,6 +2,7 @@ from lago_python_client.clients.applied_add_on_client import AppliedAddOnClient
 from lago_python_client.clients.applied_coupon_client import AppliedCouponClient
 from lago_python_client.clients.subscription_client import SubscriptionClient
 from lago_python_client.clients.customer_client import CustomerClient
+from lago_python_client.clients.invoice_client import InvoiceClient
 from lago_python_client.clients.event_client import EventClient
 from lago_python_client.clients.webhook_client import WebhookClient
 from urllib.parse import urljoin
@@ -30,6 +31,9 @@ class Client:
     def customers(self):
         return CustomerClient(self.base_api_url(), self.api_key)
 
+    def invoices(self):
+        return InvoiceClient(self.base_api_url(), self.api_key)
+
     def applied_coupons(self):
         return AppliedCouponClient(self.base_api_url(), self.api_key)
 
